@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+# ruff: noqa: F401
 """
 Import all step definitions of this step-library.
 Step definitions are automatically registered in "behave.step_registry".
@@ -9,4 +10,7 @@ from __future__ import absolute_import
 # -- IMPORT STEP-LIBRARY: behave4cmd0
 import behave4cmd0.command_steps
 import behave4cmd0.note_steps
-import behave4cmd0.log.steps
+import behave4cmd0.log_steps
+import behave4cmd0.environment_steps
+import behave4cmd0.filesystem_steps
+import behave4cmd0.workdir_steps
